XMLHttpRequest extension type

@AvailableInWorkers("window_and_worker_except_service")

XMLHttpRequest (XHR) objects are used to interact with servers. You can retrieve data from a URL without having to do a full page refresh. This enables a Web page to update just part of a page without disrupting what the user is doing.

Despite its name, XMLHttpRequest can be used to retrieve any type of data, not just XML.

If your communication needs to involve receiving event data or message data from a server, consider using server-sent events through the EventSource interface. For full-duplex communication, WebSockets may be a better choice.


API documentation sourced from MDN Web Docs.

on
Implemented types
Available extensions

Constructors

XMLHttpRequest()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDefinedAndNotNull → bool

Available on JSAny?, provided by the NullableUndefineableJSAnyExtension extension

no setter
isNull → bool

Available on JSAny?, provided by the NullableUndefineableJSAnyExtension extension

Whether this value corresponds to JavaScript null.
no setter
isTruthy → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of !!this in JavaScript.
no setter
isUndefined → bool

Available on JSAny?, provided by the NullableUndefineableJSAnyExtension extension

Whether this value corresponds to JavaScript undefined.
no setter
isUndefinedOrNull → bool

Available on JSAny?, provided by the NullableUndefineableJSAnyExtension extension

no setter
not → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of !this in JavaScript.
no setter
onabort ↔ EventHandler?
getter/setter pairinherited
onError → Stream<ProgressEvent>

Available on XMLHttpRequest, provided by the XHRGetters extension

no setter
onerror ↔ EventHandler?
getter/setter pairinherited
onLoad → Stream<ProgressEvent>

Available on XMLHttpRequest, provided by the XHRGetters extension

no setter
onload ↔ EventHandler?
getter/setter pairinherited
onloadend ↔ EventHandler?
getter/setter pairinherited
onloadstart ↔ EventHandler?
getter/setter pairinherited
onProgress → Stream<ProgressEvent>

Available on XMLHttpRequest, provided by the XHRGetters extension

no setter
onprogress ↔ EventHandler?
getter/setter pairinherited
onReadyStateChange → Stream<Event>

Available on XMLHttpRequest, provided by the XHRGetters extension

no setter
onreadystatechange ↔ EventHandler?
getter/setter pair
ontimeout ↔ EventHandler?
getter/setter pairinherited
readyState → int
@AvailableInWorkers("window_and_worker_except_service")
no setter
response → JSAny?
@AvailableInWorkers("window_and_worker_except_service")
no setter
responseHeaders → Map<String, String>

Available on XMLHttpRequest, provided by the XMLHttpRequestGlue extension

Returns all response headers as a key-value map.
no setter
responseText → String
@AvailableInWorkers("window_and_worker_except_service")
no setter
responseType ↔ String
@AvailableInWorkers("window_and_worker_except_service")
getter/setter pair
responseURL → String
@AvailableInWorkers("window_and_worker_except_service")
no setter
responseXML → Document?
@AvailableInWorkers("window_and_worker_except_service")
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
@AvailableInWorkers("window_and_worker_except_service")
no setter
statusText → String
@AvailableInWorkers("window_and_worker_except_service")
no setter
timeout ↔ int
@AvailableInWorkers("window_and_worker_except_service")
getter/setter pair
upload → XMLHttpRequestUpload
@AvailableInWorkers("window_and_worker_except_service")
no setter
withCredentials ↔ bool
@AvailableInWorkers("window_and_worker_except_service")
getter/setter pair

Methods

abort() → void
@AvailableInWorkers("window_and_worker_except_service")
add(JSAny? any) → JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this + any in JavaScript.
addEventListener(String type, EventListener? callback, [JSAny options]) → void
The addEventListener() method of the EventTarget interface sets up a function that will be called whenever the specified event is delivered to the target.
inherited
and(JSAny? any) → JSAny?

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this && any in JavaScript.
callMethod<R extends JSAny?>(JSAny method, [JSAny? arg1, JSAny? arg2, JSAny? arg3, JSAny? arg4]) → R

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Calls method on this JSObject with up to four arguments.
callMethodVarArgs<R extends JSAny?>(JSAny method, [List<JSAny?>? arguments]) → R

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Calls method on this JSObject with a variable number of arguments.
dartify() → Object?

Available on JSAny?, provided by the JSAnyUtilityExtension extension

Converts a JavaScript JSON-like value to the Dart equivalent if possible.
delete(JSAny property) → JSBoolean

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Deletes the property with key property from this JSObject.
dispatchEvent(Event event) → bool
The dispatchEvent() method of the EventTarget sends an Event to the object, (synchronously) invoking the affected event listeners in the appropriate order. The normal event processing rules (including the capturing and optional bubbling phase) also apply to events dispatched manually with dispatchEvent().
inherited
divide(JSAny? any) → JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this / any in JavaScript.
equals(JSAny? any) → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this == any in JavaScript.
exponentiate(JSAny? any) → JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this ** any in JavaScript.
getAllResponseHeaders() → String
@AvailableInWorkers("window_and_worker_except_service")
getProperty<R extends JSAny?>(JSAny property) → R

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

The value of the property key property of this JSObject.
getResponseHeader(String name) → String?
@AvailableInWorkers("window_and_worker_except_service")
greaterThan(JSAny? any) → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this > any in JavaScript.
greaterThanOrEqualTo(JSAny? any) → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this >= any in JavaScript.
has(String property) → bool

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Shorthand helper for hasProperty to check whether this JSObject contains the property key property, but takes and returns a Dart value.
hasProperty(JSAny property) → JSBoolean

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Whether or not this JSObject contains the property key property.
instanceof(JSFunction<Function> constructor) → bool

Available on JSAny?, provided by the JSAnyUtilityExtension extension

Whether this JSAny? is an instanceof constructor.
instanceOfString(String constructorName) → bool

Available on JSAny?, provided by the JSAnyUtilityExtension extension

Whether this JSAny? is an instanceof the constructor that is defined by constructorName, which is looked up in the globalContext.
lessThan(JSAny? any) → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this < any in JavaScript.
lessThanOrEqualTo(JSAny? any) → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this <= any in JavaScript.
modulo(JSAny? any) → JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this % any in JavaScript.
multiply(JSAny? any) → JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this * any in JavaScript.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(JSAny? any) → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this != any in JavaScript.
open(String method, String url, [bool async, String? username, String? password]) → void
@AvailableInWorkers("window_and_worker_except_service")
or(JSAny? any) → JSAny?

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this || any in JavaScript.
overrideMimeType(String mime) → void
@AvailableInWorkers("window_and_worker_except_service")
removeEventListener(String type, EventListener? callback, [JSAny options]) → void
The removeEventListener() method of the EventTarget interface removes an event listener previously registered with EventTarget.addEventListener from the target. The event listener to be removed is identified using a combination of the event type, the event listener function itself, and various optional options that may affect the matching process; see Matching event listeners for removal.
inherited
send([JSAny? body]) → void
@AvailableInWorkers("window_and_worker_except_service")
setProperty(JSAny property, JSAny? value) → void

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Write the value of property key property of this JSObject.
setRequestHeader(String name, String value) → void
@AvailableInWorkers("window_and_worker_except_service")
strictEquals(JSAny? any) → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this === any in JavaScript.
strictNotEquals(JSAny? any) → JSBoolean

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this !== any in JavaScript.
subtract(JSAny? any) → JSAny

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this - any in JavaScript.
toString() → String
A string representation of this object.
inherited
typeofEquals(String typeString) → bool

Available on JSAny?, provided by the JSAnyUtilityExtension extension

Whether the result of typeof on this JSAny? is typeString.
unsignedRightShift(JSAny? any) → JSNumber

Available on JSAny?, provided by the JSAnyOperatorExtension extension

The result of this >>> any in JavaScript.

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](String property) → JSAny?

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Shorthand helper for getProperty to get the value of the property key property of this JSObject, but takes a Dart value.
operator []=(String property, JSAny? value) → void

Available on JSObject, provided by the JSObjectUnsafeUtilExtension extension

Shorthand helper for setProperty to write the value of the property key property of this JSObject, but takes a Dart value.

Constants

DONE → const int
HEADERS_RECEIVED → const int
LOADING → const int
OPENED → const int
UNSENT → const int